==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DataSourceRowExpansionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceRowExpansionChangedEventArgsDescription } from "./DataSourceRowExpansionChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceRowExpansionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, _super);
    function DataSourceRowExpansionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b(a);
        a.u("DataSourceRowExpansionChangedEventArgs", function () { return new DataSourceRowExpansionChangedEventArgsDescription(); });
        a.t("DataSourceRowExpansionChangedEventArgs", DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.$t = markType(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, 'DataSourceRowExpansionChangedEventArgsDescriptionMetadata');
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceRowExpansionChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceRowExpansionChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataSourceRowExpansionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceRowExpansionChangedEventArgsDescription } from "./DataSourceRowExpansionChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceRowExpansionChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, _super);
    function DataSourceRowExpansionChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b(a);
        a.aa("DataSourceRowExpansionChangedEventArgs", function () { return new DataSourceRowExpansionChangedEventArgsDescription(); });
        a.z("DataSourceRowExpansionChangedEventArgs", DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.$t = markType(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, 'DataSourceRowExpansionChangedEventArgsDescriptionMetadata');
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceRowExpansionChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceRowExpansionChangedEventArgsDescriptionMetadata };
